ThumbSize	= 80
ThumbRows	= 5
ThumbPosition	= se

ImageDir	= /tmp/pics
ImagePosition	= c
TitleDirs	= 1
TitleIndex	= 1

SlideShowDelay	= 3000

SmallFont	= {DejaVu Sans Mono} 8
SelectionFont	= {DejaVu Sans} 6

MaxX		= 1920
MaxY		= 1200

ConfirmDelete	= 0
RemoveTarget	= 1

keys_quit_all	= Shift-Q Control-Q Key-grave
